﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Media.Imaging;
using System.Windows.Browser;

namespace MoreControls {
    public partial class ItemSampleControl : UserControl {
        public ItemSampleControl() {
            InitializeComponent();
        }

        string _source = null;
        /// <summary>
        /// The source of the image to display for the toolbar item
        /// </summary>
        public string ImageSource {
            get { return _source; }
            set {
                Uri uri = new Uri(value, UriKind.RelativeOrAbsolute);
                BitmapImage bitmap = new BitmapImage(uri);
                imageMain.Source = bitmap;
            }
        }

        /// <summary>
        /// Title of the control
        /// </summary>
        public string Title {
            get { return linkTitle.Content.ToString(); }
            set { linkTitle.Content = value; }
        }

        /// <summary>
        /// Link to item
        /// </summary>
        public string Link {
            get { return linkTitle.NavigateUri.OriginalString; }
            set { linkTitle.NavigateUri = new Uri(value, UriKind.RelativeOrAbsolute); }
        }

        /// <summary>
        /// Link to source code
        /// </summary>
        public string LinkSource {
            get { return linkSource.NavigateUri.OriginalString; }
            set { linkSource.NavigateUri = new Uri(value, UriKind.RelativeOrAbsolute); }
        }

        /// <summary>
        /// Link to tutorial
        /// </summary>
        public string LinkTutorial {
            get { return linkTutorial.NavigateUri.OriginalString; }
            set {
                linkTutorial.NavigateUri = new Uri(value, UriKind.RelativeOrAbsolute);
                if (string.IsNullOrEmpty(value)) {
                    linkTutorial.Visibility = Visibility.Collapsed;
                }
                else {
                    linkTutorial.Visibility = Visibility.Visible;
                }
            }
        }

        /// <summary>
        /// More information about the sample/demo or item
        /// </summary>
        public string MoreInfo {
            get { return textMoreInfo.Text; }
            set { textMoreInfo.Text = value; }
        }

        /// <summary>
        /// Shows the control using animation
        /// </summary>
        public void Appear() {
            this.Visibility = Visibility.Visible;
            animRootControlAppear.Begin();
        }

        /// <summary>
        /// hides the control using animation
        /// </summary>
        public void Disappear() {
            animRootControlDisappear.Begin();
        }

        private void UserControl_MouseEnter(object sender, MouseEventArgs e) {
            animAppear.Begin();
        }

        private void UserControl_MouseLeave(object sender, MouseEventArgs e) {
            animDisappear.Begin();
            animCollapse.Begin();
            linkInfo.Content = "More Info";
            _isExpanded = false;
        }

        /// <summary>
        /// true if the more info is expanded, false otherwise
        /// </summary>
        bool _isExpanded = false;
        private void linkInfo_Click(object sender, RoutedEventArgs e) {
            if (_isExpanded) {
                animCollapse.Begin();
                linkInfo.Content = "More Info";
            }
            else {
                animExpand.Begin();
                linkInfo.Content = "Hide Info";
            }

            _isExpanded = !_isExpanded;

        }

        private void LayoutRoot_MouseLeftButtonUp(object sender, MouseButtonEventArgs e) {
            HtmlPage.Window.Navigate(linkTitle.NavigateUri);
        }

        private void animRootControlDisappear_Completed(object sender, EventArgs e) {
            this.Visibility = Visibility.Collapsed;
        }
    }
}
