﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Media.Imaging;
using System.Diagnostics;

namespace MoreControls
{
    public partial class LiveImage : UserControl
    {
        public static readonly DependencyProperty VideoProperty =
            DependencyProperty.Register("Video", typeof(string), typeof(LiveImage),
            new PropertyMetadata(new PropertyChangedCallback(LiveImage.OnVideoPropertyChanged)));

        /// <summary>
        /// Location of the video file (e.g. nokola.com/video.wmv)
        /// </summary>
        public string Video
        {
            get { return (string)GetValue(VideoProperty); }
            set { SetValue(VideoProperty, value); }
        }

        public static readonly DependencyProperty PreviewProperty =
            DependencyProperty.Register("Preview", typeof(string), typeof(LiveImage),
            new PropertyMetadata(new PropertyChangedCallback(LiveImage.OnPreviewPropertyChanged)));

        /// <summary>
        /// The video preview picture to display before the video is loaded
        /// Usually this is the first frame of the video or some other key picture 
        /// representing the video
        /// </summary>
        public string Preview
        {
            get { return (string)GetValue(PreviewProperty); }
            set { SetValue(PreviewProperty, value); }
        }

        private static void OnVideoPropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            MoreControls.LiveImage control = (MoreControls.LiveImage)d;
            control.media.Source = new Uri(e.NewValue.ToString(), UriKind.RelativeOrAbsolute);
        }

        private static void OnPreviewPropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            MoreControls.LiveImage control = (MoreControls.LiveImage)d;
            control.imgFirstFrame.Source = new BitmapImage(new Uri(e.NewValue.ToString(), UriKind.RelativeOrAbsolute)); ;
        }

        public LiveImage()
        {
            InitializeComponent();
        }

        private void media_MouseEnter(object sender, MouseEventArgs e)
        {
            //Play();
        }

        private void media_MouseLeave(object sender, MouseEventArgs e)
        {
            //Pause();
        }

        /// <summary>
        /// Resume playing of the live video
        /// </summary>
        public void Play()
        {
            Debug.WriteLine("Play");
            media.Play();
        }

        /// <summary>
        /// Pause the live video playback
        /// </summary>
        public void Pause()
        {
            Debug.WriteLine("Pause");
            media.Pause();
        }

        private void media_MediaEnded(object sender, RoutedEventArgs e)
        {
            // if we reached the end of the video, transition smoothly to the beginning by fading out 
            // to the first frame image
            animVideoFadeOut.Begin();
        }

        private void animVideoFadeOut_Completed(object sender, EventArgs e)
        {
            // video fade out is complete, reset the video and show it on screen
            media.Stop();
            animVideoFadeInCompensation.Begin();
        }
    }
}
