﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Media.Imaging;

namespace MoreControls {
    public partial class TearDropItem : UserControl {
        public delegate void ClickHandler();

        /// <summary>
        /// Called when the user clicks the item
        /// </summary>
        public event ClickHandler Click;

        /// <summary>
        /// Uri to navigate to when clicked
        /// </summary>
        public string NavigateUri { get; set; }

        /// <summary>
        /// true to open link in new window, false to open link in current window
        /// default is false
        /// </summary>
        public bool OpenInNewWindow { get; set; }

        /// <summary>
        /// Title of the toolbar item
        /// </summary>
        public string Title {
            get { return textTitle.Text; }
            set {
                textTitle.Text = value;
                //textTitle1.Text = value;
            }
        }

        string _source = null;
        /// <summary>
        /// The source of the image to display for the toolbar item
        /// </summary>
        public string ImageSource {
            get { return _source; }
            set {
                Uri uri = new Uri(value, UriKind.RelativeOrAbsolute);
                BitmapImage bitmap = new BitmapImage(uri);
                imageMain.Source = bitmap;

                bitmap = new BitmapImage(uri);
                imageReflection.Source = bitmap;
            }
        }

        /// <summary>
        /// The title foreground brush
        /// </summary>
        public Brush TitleBrush {
            get { return textTitle.Foreground; }
            set { textTitle.Foreground = value; }
        }

        public TearDropItem() {
            InitializeComponent();
        }

        private void UserControl_MouseLeftButtonUp(object sender, MouseButtonEventArgs e) {
            if (NavigateUri != null) {
                if (OpenInNewWindow) {
                    System.Windows.Browser.HtmlPage.Window.Navigate(new Uri(NavigateUri, UriKind.Absolute), "_new");
                }
                else {
                    System.Windows.Browser.HtmlPage.Window.Navigate(new Uri(NavigateUri, UriKind.Absolute));
                }
            }

            if (Click != null) {
                Click();
            }
        }

        private void UserControl_MouseEnter(object sender, MouseEventArgs e) {
            animSelect.Begin();
        }

        private void UserControl_MouseLeave(object sender, MouseEventArgs e) {
            animDeselect.Begin();
        }
    }
}
